@@ -587,7 +587,7 @@ class Slab(s_base.Base):
     COMMIT_PERIOD = float(os.environ.get('SYN_SLAB_COMMIT_PERIOD', '0.2'))
 
     # warn if commit takes too long
-    WARN_COMMIT_TIME_MS = int(float(os.environ.get('SYN_SLAB_COMMIT_WARN', '5.0')) * 1000)
+    WARN_COMMIT_TIME_MS = int(float(os.environ.get('SYN_SLAB_COMMIT_WARN', '1.0')) * 1000)
 
     DEFAULT_MAPSIZE = s_const.gibibyte
     DEFAULT_GROWSIZE = None
@@ -713,7 +713,17 @@ class Slab(s_base.Base):
 
         self._saveOptsFile()
 
-        self.lenv = lmdb.open(str(path), **opts)
+        try:
+            self.lenv = lmdb.open(str(path), **opts)
+        except lmdb.LockError as e:  # pragma: no cover
+            # This is difficult to test since it requires two processes to open the slab with
+            # the same pid. In practice this typically occurs when there are two docker
+            # containers running from different process namespaces, whose process pids are
+            # the same, opening the same lmdb database. That isn't a supported configuration
+            # and we just need to catch that error.
+            mesg = f'Unable to obtain lock on {path}. Another process may have this file locked. {e}'
+            raise s_exc.LmdbLock(mesg=mesg, path=path) from None
+
         self.allslabs[path] = self
 
         self.scans = set()
