@@ -14,6 +14,9 @@ class MsgPackTest(s_t_utils.SynTest):
         byts = s_msgpack.en(('hehe', 10))
         self.eq(byts, b'\x92\xa4hehe\n')
 
+        byts = s_msgpack._fallback_en(('hehe', 10))
+        self.eq(byts, b'\x92\xa4hehe\n')
+
     def test_msgpack_un(self):
         item = s_msgpack.un(b'\x92\xa4hehe\n')
         self.eq(item, ('hehe', 10))
@@ -34,14 +37,14 @@ class MsgPackTest(s_t_utils.SynTest):
         self.len(0, unpk.feed(b's'))
         self.eq(unpk.feed(b'i')[0], (5, 'visi'))
 
-    def test_msgpack_iterfd(self):
+    def checkIterfd(self, enfunc):
         t0 = ('5678', {'key': 1})
         t1 = ('1234', {'key': 'haha'})
 
         with self.getTestDir() as fdir:
             fd = s_common.genfile(fdir, 'test.mpk')
             for obj in (t0, t1):
-                fd.write(s_msgpack.en(obj))
+                fd.write(enfunc(obj))
             fd.close()
 
             fd = s_common.genfile(fdir, 'test.mpk')
@@ -52,15 +55,18 @@ class MsgPackTest(s_t_utils.SynTest):
             self.sorteq(items, [t0, t1])
 
             fd.close()
+    def test_msgpack_iterfd(self):
+        self.checkIterfd(s_msgpack.en)
+        self.checkIterfd(s_msgpack._fallback_en)
 
-    def test_msgpack_iterfile(self):
+    def checkIterfile(self, enfunc):
         t0 = ('5678', {'key': 1})
         t1 = ('1234', {'key': 'haha'})
 
         with self.getTestDir() as fdir:
             fd = s_common.genfile(fdir, 'test.mpk')
             for obj in (t0, t1):
-                fd.write(s_msgpack.en(obj))
+                fd.write(enfunc(obj))
             fd.close()
 
             gen = s_msgpack.iterfile(s_common.genpath(fdir, 'test.mpk'))
@@ -71,18 +77,22 @@ class MsgPackTest(s_t_utils.SynTest):
 
             fd.close()
 
-    def test_msgpack_loadfile(self):
+    def test_msgpack_iterfile(self):
+        self.checkIterfile(s_msgpack.en)
+        self.checkIterfile(s_msgpack._fallback_en)
+
+    def checkLoadfile(self, enfunc):
         t0 = ('5678', {'key': 1})
         t1 = ('1234', {'key': 'haha'})
 
         with self.getTestDir() as fdir:
             fd = s_common.genfile(fdir, 'oneobj.mpk')
-            fd.write(s_msgpack.en(t0))
+            fd.write(enfunc(t0))
             fd.close()
 
             fd = s_common.genfile(fdir, 'twoobjs.mpk')
             for obj in (t0, t1):
-                fd.write(s_msgpack.en(obj))
+                fd.write(enfunc(obj))
             fd.close()
 
             data = s_msgpack.loadfile(s_common.genpath(fdir, 'oneobj.mpk'))
@@ -91,7 +101,11 @@ class MsgPackTest(s_t_utils.SynTest):
             # Files containing multiple objects are not supported
             self.raises(msgpack.exceptions.ExtraData, s_msgpack.loadfile, s_common.genpath(fdir, 'twoobjs.mpk'))
 
-    def test_msgpack_types(self):
+    def test_msgpack_loadfile(self):
+        self.checkLoadfile(s_msgpack.en)
+        self.checkLoadfile(s_msgpack._fallback_en)
+
+    def checkTypes(self, enfunc):
         # This is a future-proofing test for msgpack to ensure that
         buf = b'\x92\xa4hehe\x85\xa3str\xa41234\xa3int\xcd\x04\xd2\xa5float\xcb@(\xae\x14z\xe1G\xae\xa3bin\xc4\x041234\xa9realworld\xac\xc7\x8b\xef\xbf\xbd\xed\xa1\x82\xef\xbf\xbd\x12'
         struct = (
@@ -144,15 +158,18 @@ class MsgPackTest(s_t_utils.SynTest):
         }
         ustruct2 = s_msgpack.un(buf2)
         self.eq(ustruct2, struct2)
-        pbuf2 = s_msgpack.en(ustruct2)
+        pbuf2 = enfunc(ustruct2)
         self.eq(buf2, pbuf2)
 
-    def test_msgpack_large_data(self):
+    def test_msgpack_types(self):
+        self.checkTypes(s_msgpack.en)
+        self.checkTypes(s_msgpack._fallback_en)
 
+    def checkLargeData(self, enfunc):
         big_string = s_const.mebibyte * 129 * 'V'
         struct = ('test', {'key': big_string})
 
-        buf = s_msgpack.en(struct)
+        buf = enfunc(struct)
 
         unpacked_struct = s_msgpack.un(buf)
         self.eq(struct, unpacked_struct)
@@ -173,18 +190,26 @@ class MsgPackTest(s_t_utils.SynTest):
         self.len(1, objs)
         self.eq(objs[0], (135266320, struct))
 
-    def test_msgpack_bad_types(self):
-        self.raises(s_exc.NotMsgpackSafe, s_msgpack.en, {1, 2})
-        self.raises(s_exc.NotMsgpackSafe, s_msgpack.en, Exception())
-        self.raises(s_exc.NotMsgpackSafe, s_msgpack.en, s_msgpack.en)
+    def test_msgpack_large_data(self):
+        self.checkLargeData(s_msgpack.en)
+        self.checkLargeData(s_msgpack._fallback_en)
+
+    def checkBadTypes(self, enfunc):
+        self.raises(s_exc.NotMsgpackSafe, enfunc, {1, 2})
+        self.raises(s_exc.NotMsgpackSafe, enfunc, Exception())
+        self.raises(s_exc.NotMsgpackSafe, enfunc, s_msgpack.en)
         # too long
         with self.raises(s_exc.NotMsgpackSafe) as cm:
-            s_msgpack.en({'longlong': 45234928034723904723906})
+            enfunc({'longlong': 45234928034723904723906})
         self.isin('OverflowError', cm.exception.get('mesg'))
 
-    def test_msgpack_surrogates(self):
+    def test_msgpack_bad_types(self):
+        self.checkBadTypes(s_msgpack.en)
+        self.checkBadTypes(s_msgpack._fallback_en)
+
+    def checkSurrogates(self, enfunc):
         bads = '\u01cb\ufffd\ud842\ufffd\u0012'
-        obyts = s_msgpack.en(bads)
+        obyts = enfunc(bads)
         self.isinstance(obyts, bytes)
 
         outs = s_msgpack.un(obyts)
@@ -208,3 +233,7 @@ class MsgPackTest(s_t_utils.SynTest):
         ret = unpk.feed(obyts)
         self.len(1, ret)
         self.eq([(13, bads)], ret)
+
+    def test_msgpack_surrogates(self):
+        self.checkSurrogates(s_msgpack.en)
+        self.checkSurrogates(s_msgpack._fallback_en)
